# GAM Calendar Resources Command Reference

Adapted with love from the [GAM Cheat Sheet](https://gamcheatsheet.com/)

***

## gam create resource \<id\> \<Name\> [parameters]


## gam update resource \<id\> [name \<Name\>] [parameters]

## where parameters are:
* [description \<description\>]
* [type \<type\>]
* [building \<building\>]
* [capacity \<number\>]
* [features \<features\>]
* [floor \<floor\>]
* [floorsection \<floorsection\>]

## gam info|delete resource \<id\>

## gam print resources
* [id]
* [description]
* [email]
* [type]
* [allfields]
* [todrive]

## gam create building \<name\>
* [id \<id\>]
* [latitude \<latitude\>]
* [longitude \<longitude\>]
* [description \<description\>]
* [floors \<floors\>]

## gam update building \<name or id:id\>
* [name \<name\>]
* [latitude \<latitude\>]
* [longitude \<longitude\>]
* [description \<description\>]
* [floors \<floors\>]

## gam info building \<name or id:id\>

## gam delete building \<name or id:id\>

## gam create feature name \<name\>

## gam update feature \<name\> name \<newname\>

## gam delete feature \<name\>
